function [data, names]=readsamps(datadir,filestem,nfiles,s8fix,hfund,ncols)
%READSAMPS Read in samples files.
%   [DATA,NAMES] = READSAMPS(DATADIR,FILESTEM) reads in the samples in 
%   file [DATADIR,FILESTEM,'.txt.'] into array DATA. It also creates 
%   an array NAMES which corresponds to the parameter names in the default
%   cosmomc implementation.
%
%   [DATA,NAMES] = READSAMPS(DATADIR,FILESTEM,NFILES) automatically reads
%   in multiple samples files [DATADIR,FILESTEM,'_1.txt'] up to NFILES 
%   into a single array DATA.

if (~exist('nfiles')) nfiles=0; end
if (~exist('s8fix')) s8fix=0; end
if (~exist('hfund')) hfund=1; end

%if (~exist('ncols')) ncols=19; end
if (~exist('ncols')) ncols=21; end

for ifile=1:nfiles
  filename=[datadir,filestem,'_',num2str(ifile),'.txt']
  fid=fopen(filename)
  datatmp=fscanf(fid,'%g');
  nsamp=length(datatmp)/ncols;
  datatmp=reshape(datatmp,[ncols,nsamp]);
  fclose(fid);
  % append this to the full set of samples
  if (ifile==1)
    data=datatmp;
  else
    data=[data datatmp];
  end
end

if (nfiles==0)
  filename=[datadir,filestem,'.txt']
  fid=fopen(filename)
  datatmp=fscanf(fid,'%g');
  nsamp=length(datatmp)/ncols;
  data=reshape(datatmp,[ncols,nsamp]);
  fclose(fid);
end

% 3    4     5     6   7   8   9 10 11 12 13 14  15  16 17  18 19  
% obh2 odmh2 omv   zre omk fnu w ns nt -  as ast tau h  age om sig8
% for this file sig8=sqrt(as).*1e-5.*data(19,:);
if (s8fix) data(19,:)=sqrt(data(13,:)).*1e-5.*data(19,:); end
if (hfund)
  ih=5;
else
  ih=16;
end
data(ih,:)=data(ih,:)/100; % I prefer h rather than H0

% make h appear fundamental
if (hfund==0)
  tmp=data(5,:);
  data(5,:)=data(16,:);
  data(16,:)=tmp;
end  

names=[...
'Weight          ';...
'Likelihood      ';...
'\Omega_b h^2    ';...
'\Omega_{DM} h^2 ';...
'h               ';...
'z_{re}          ';...
'\Omega_{\rm K}  ';...
'f_{nu}          ';...
'w               ';...
'n_s             ';...
'n_t             ';...
'-               ';...
'A_s             ';...
'A_t             ';...
'-               ';...
'\Omega_{\Lambda}';...
'Age             ';...
'\Omega_m        ';...
'\sigma_8        ';...
'\tau            ']
